Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3589)

Unified Diff: chrome/browser/ui/views/payments/payment_request_item_list.h

Issue 2759253002: [Web Payments] Implement item selection in lists. (Closed)
Patch Set: Assert back navigation in browser tests. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/payment_request_item_list.h
diff --git a/chrome/browser/ui/views/payments/payment_request_item_list.h b/chrome/browser/ui/views/payments/payment_request_item_list.h
index 5ff845900f3169f2b31131fa6adab0bcb01c0c44..b2d360ed2b91eec7c9bed453d070be6b67b81f53 100644
--- a/chrome/browser/ui/views/payments/payment_request_item_list.h
+++ b/chrome/browser/ui/views/payments/payment_request_item_list.h
@@ -45,9 +45,9 @@ class PaymentRequestItemList {
views::View* GetItemView();
bool selected() const { return selected_; }
- // Changes the selected state of this item to |selected| and calls
- // SelectedStateChanged.
- void SetSelected(bool selected);
+ // Changes the selected state of this item to |selected|.
+ // SelectedStateChanged is called if |notify| is true.
+ void SetSelected(bool selected, bool notify);
// Returns a pointer to the PaymentRequestItemList that owns this object.
PaymentRequestItemList* list() { return list_; }

Powered by Google App Engine
This is Rietveld 408576698